@@ -17,6 +17,9 @@
 # CAM签名/鉴权错误。
 AUTHFAILURE = 'AuthFailure'
 
+# 请求未授权。请参考 [CAM](https://cloud.tencent.com/document/product/598) 文档对鉴权的说明。
+AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
+
 # DryRun 操作，代表请求将会是成功的，只是多传了 DryRun 参数。
 DRYRUNOPERATION = 'DryRunOperation'
 
@@ -47,6 +50,9 @@ FAILEDOPERATION_CANNOTBEDELETEDISSUED = 'FailedOperation.CannotBeDeletedIssued'
 # 免费证书申请1小时内不允许删除。
 FAILEDOPERATION_CANNOTBEDELETEDWITHINHOUR = 'FailedOperation.CannotBeDeletedWithinHour'
 
+# 导播台不存在。
+FAILEDOPERATION_CASTERNOTFOUND = 'FailedOperation.CasterNotFound'
+
 # 证书已存在。
 FAILEDOPERATION_CERTIFICATEEXISTS = 'FailedOperation.CertificateExists'
 
@@ -98,6 +104,9 @@ FAILEDOPERATION_DOMAINNEEDVERIFYOWNER = 'FailedOperation.DomainNeedVerifyOwner'
 # 免费证书数量超出限制。
 FAILEDOPERATION_EXCEEDSFREELIMIT = 'FailedOperation.ExceedsFreeLimit'
 
+# 获取数据失败。
+FAILEDOPERATION_GETDATAFAILED = 'FailedOperation.GetDataFailed'
+
 # 无法获取水印 url。
 FAILEDOPERATION_GETPICTUREURLERROR = 'FailedOperation.GetPictureUrlError'
 
